@@ -2,15 +2,13 @@
 #
 # Short example of use for Device::Gsm class
 # Script that reads all SMS stored on SIM
-#
-# $Id: read_messages.pl,v 1.5 2006/04/20 20:05:45 cosimo Exp $
 
 use strict;
 use lib '../lib';
 use lib '../';
-use Gsm;
+use Device::Gsm;
 
-print "\nthis is ", '$Id: read_messages.pl,v 1.5 2006/04/20 20:05:45 cosimo Exp $', "\n";
+print "\nthis is read_messages.pl\n";
 print "\nTrying to read all messages you have on your SIM card...\n";
 
 my $port = $ENV{'DEV_GSM_PORT'} || ( $^O =~ /Win/ ? 'COM2' : '/dev/ttyS1' );
