@@ -1,13 +1,11 @@
 #!/usr/bin/perl
 #
 # Short example of use for Device::Gsm class
-#
-# $Id: send_sms.pl,v 1.2 2002/04/29 17:03:46 cosimo Exp $
 
 use strict;
 use Device::Gsm;
 
-print "\nthis is ", '$Id: send_sms.pl,v 1.2 2002/04/29 17:03:46 cosimo Exp $', "\n";
+print "\nthis is send_sms.pl\n";
 print "I hope I can send an SMS on your GSM phone attached to...\n";
 
 my $port = $^O =~ /Win/ ? 'COM2' : '/dev/ttyS1';
@@ -26,7 +24,7 @@ $mypin ||= $pin;
 $mypin =~ s/\D//g;
 $mypin = substr( $mypin, 0, 4 );
 
-my $gsm = new Device::Gsm( port => $myport, pin => $mypin, log => 'file,send.log', loglevel=>'info' );
+my $gsm = new Device::Gsm( port => $myport, pin => $mypin, log => 'file,send.log' );
 
 die "cannot create Device::Gsm object!" unless $gsm;
 
@@ -66,8 +64,7 @@ $content = substr( $content, 0, 160 );
 my $lOk = $gsm->send_sms(
 	content => $content,
 	recipient => $number,
-	class     => 'normal',    # try `flash'
-    status_report => 1
+	class     => 'normal'     # try `flash'
 );
 
 if( $lOk ) {
